pub struct BackupCmd {Show 22 fields
cli_sources: Vec<String>,
cli_name: Vec<String>,
name: Option<String>,
stdin_filename: String,
stdin_command: Option<CommandInput>,
as_path: Option<PathBuf>,
pub no_scan: bool,
json: bool,
long: bool,
init: bool,
ignore_save_opts: LocalSourceSaveOptions,
parent_opts: ParentOptions,
excludes: Excludes,
ignore_filter_opts: LocalSourceFilterOptions,
snap_opts: SnapshotOptions,
key_opts: KeyOptions,
config_opts: ConfigOptions,
hooks: Hooks,
snapshots: Vec<Self>,
sources: Vec<String>,
pub metrics_job: Option<String>,
metrics_labels: BTreeMap<String, String>,
}Expand description
backup subcommand
Fields
cli_sources: Vec<String>Backup source (can be specified multiple times), use - for stdin. If no source is given, uses all sources defined in the config file
cli_name: Vec<String>Backup sources defined in the config profile by the given name (can be specified multiple times)
name: Option<String>stdin_filename: StringSet filename to be used when backing up from stdin
stdin_command: Option<CommandInput>Start the given command and use its output as stdin
as_path: Option<PathBuf>Manually set backup path in snapshot
no_scan: boolDon’t scan the backup source for its size - this disables ETA estimation for backup.
json: boolOutput generated snapshot in json format
long: boolShow detailed information about generated snapshot
init: boolInitialize repository, if it doesn’t exist yet
ignore_save_opts: LocalSourceSaveOptionsNode save options
parent_opts: ParentOptionsParent processing options
excludes: ExcludesExclude options
ignore_filter_opts: LocalSourceFilterOptionsExclude options for local source
snap_opts: SnapshotOptionsSnapshot options
key_opts: KeyOptionsKey options (when using –init)
config_opts: ConfigOptionsConfig options (when using –init)
hooks: HooksHooks to use
snapshots: Vec<Self>Backup snapshots to generate
sources: Vec<String>Backup source, used within config file
metrics_job: Option<String>Job name for the metrics. Default: rustic-backup
metrics_labels: BTreeMap<String, String>Additional labels to set to generated metrics
Implementations
Sourceimpl BackupCmd
impl BackupCmd
fn inner_run(&self, repo: Repo) -> Result<()>
fn get_snapshots_to_backup(&self) -> Result<Vec<(Self, PathList)>>
fn hooks(&self, hooks: &Hooks, action: &str, source: impl Display) -> Hooks
fn backup_snapshot( self, source: PathList, repo: &Repository<IndexedIdsStatus>, ) -> Result<()>