pub struct CopyCmd {
ids: Vec<String>,
targets: Vec<String>,
init: bool,
force: bool,
key_opts: KeyOptions,
}Expand description
copy subcommand
Fields
ids: Vec<String>Snapshots to copy. If none is given, use filter options to filter from all snapshots
Snapshots can be identified the following ways: “01a2b3c4” or “latest” or “latest~N” (N >= 0)
targets: Vec<String>Target repository (can be specified multiple times)
init: boolInitialize non-existing target repositories
force: boolCopy snapshots even if the target already contains the original snapshot
key_opts: KeyOptionsKey options (when using –init)
Implementations
Sourceimpl CopyCmd
impl CopyCmd
fn inner_run(&self, repo: Repository<IndexedFullStatus>) -> Result<()>
fn copy( &self, repo: &Repository<IndexedFullStatus>, target_repo: Repo, target_opt: &AllRepositoryOptions, snapshots: &[SnapshotFile], ) -> Result<()>