pub(crate) struct DiffCmd {
snap1: Option<String>,
snap2: Option<String>,
metadata: bool,
no_content: bool,
only_identical: bool,
pub interactive: bool,
excludes: Excludes,
ignore_opts: LocalSourceFilterOptions,
}Expand description
diff subcommand
Fields
snap1: Option<String>Reference snapshot/path (uses latest, if no snapshot is given, then compare with local path)
Snapshot can be identified the following ways: “01a2b3c4” or “latest” or “latest~N” (N >= 0)
snap2: Option<String>New snapshot/path (uses PATH2 = PATH1, if not given; uses local path if no snapshot is given)
Snapshot can be identified the following ways: “01a2b3c4” or “latest” or “latest~N” (N >= 0)
metadata: boolshow differences in metadata
no_content: booldon’t check for different file contents
only_identical: boolonly show differences for identical files, this can be used for a bitrot test on the local path
interactive: boolRun in interactive UI mode
excludes: ExcludesExclude options
ignore_opts: LocalSourceFilterOptionsExclude options for local source
Implementations
Sourceimpl DiffCmd
impl DiffCmd
fn inner_run(&self, repo: Repository<IndexedFullStatus>) -> Result<()>