enum RusticCmd {
Show 22 variants
Backup(BackupCmd),
Cat(CatCmd),
Config(ConfigCmd),
Completions(CompletionsCmd),
Check(CheckCmd),
Copy(CopyCmd),
Diff(DiffCmd),
Dump(DumpCmd),
Forget(ForgetCmd),
Init(InitCmd),
Key(KeyCmd),
List(ListCmd),
Ls(LsCmd),
Merge(MergeCmd),
Snapshots(SnapshotCmd),
ShowConfig(ShowConfigCmd),
SelfUpdate(SelfUpdateCmd),
Prune(PruneCmd),
Restore(RestoreCmd),
Repair(RepairCmd),
Repoinfo(RepoInfoCmd),
Tag(TagCmd),
}Expand description
Rustic Subcommands Subcommands need to be listed in an enum.
Variants
Backup(BackupCmd)
Backup to the repository
Cat(CatCmd)
Show raw data of repository files and blobs
Config(ConfigCmd)
Change the repository configuration
Completions(CompletionsCmd)
Generate shell completions
Check(CheckCmd)
Check the repository
Copy(CopyCmd)
Copy snapshots to other repositories. Note: The target repositories must be given in the config file!
Diff(DiffCmd)
Compare two snapshots/paths Note that the exclude options only apply for comparison with a local path
Dump(DumpCmd)
dump the contents of a file in a snapshot to stdout
Forget(ForgetCmd)
Remove snapshots from the repository
Init(InitCmd)
Initialize a new repository
Key(KeyCmd)
Manage keys
List(ListCmd)
List repository files
Ls(LsCmd)
List file contents of a snapshot
Merge(MergeCmd)
Merge snapshots
Snapshots(SnapshotCmd)
Show a detailed overview of the snapshots within the repository
ShowConfig(ShowConfigCmd)
Show the configuration which has been read from the config file(s)
SelfUpdate(SelfUpdateCmd)
Update to the latest rustic release
Prune(PruneCmd)
Remove unused data or repack repository pack files
Restore(RestoreCmd)
Restore a snapshot/path
Repair(RepairCmd)
Repair a snapshot/path
Repoinfo(RepoInfoCmd)
Show general information about the repository
Tag(TagCmd)
Change tags of snapshots