pub(crate) struct FindCmd {
glob: Vec<String>,
iglob: Vec<String>,
path: Option<PathBuf>,
ids: Vec<String>,
all: bool,
show_misses: bool,
numeric_id: bool,
}Expand description
find subcommand
Fields
glob: Vec<String>pattern to find (can be specified multiple times)
iglob: Vec<String>pattern to find case-insensitive (can be specified multiple times)
path: Option<PathBuf>exact path to find
ids: Vec<String>Snapshots to search in. If none is given, use filter options to filter from all snapshots
Snapshots can be identified the following ways: “01a2b3c4” or “latest” or “latest~N” (N >= 0)
all: boolShow all snapshots instead of summarizing snapshots with identical search results
show_misses: boolAlso show snapshots which don’t contain a search result.
numeric_id: boolShow uid/gid instead of user/group
Implementations
Sourceimpl FindCmd
impl FindCmd
fn inner_run(&self, repo: Repository<IndexedFullStatus>) -> Result<()>
fn print_identical_snapshots<'a>( &self, idx: impl Iterator, g: impl Iterator<Item = &'a SnapshotFile>, )