pub struct MountCmd {
path_template: Option<String>,
time_template: Option<String>,
exclusive: bool,
file_access: Option<FilePolicy>,
mount_point: Option<PathBuf>,
snapshot_path: Option<String>,
options: Vec<String>,
}Fields
path_template: Option<String>The path template to use for snapshots. {id}, {id_long}, {time}, {username}, {hostname}, {label}, {tags}, {backup_start}, {backup_end} are replaced. [default: “[{hostname}]/[{label}]/{time}”]
time_template: Option<String>The time template to use to display times in the path template. See https://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html for format options. [default: “%Y-%m-%d_%H-%M-%S”]
exclusive: boolDon’t allow other users to access the mount point (else options allow_other,default_permissions are set)
file_access: Option<FilePolicy>How to handle access to files. [default: “forbidden” for hot/cold repositories, else “read”]
mount_point: Option<PathBuf>The mount point to use
snapshot_path: Option<String>Specify directly which snapshot/path to mount
Snapshot can be identified the following ways: “01a2b3c4” or “latest” or “latest~N” (N >= 0)
options: Vec<String>Other options to use for mount
Implementations
Sourceimpl MountCmd
impl MountCmd
fn with_default_config() -> Self
fn inner_run(&self, repo: Repository<IndexedFullStatus>) -> Result<()>