pub struct EntryPoint {
pub config: RusticConfig,
commands: RusticCmd,
}Expand description
Entry point for the application. It needs to be a struct to allow using subcommands!
Fields
config: RusticConfigcommands: RusticCmdTrait Implementations
Sourceimpl Args for EntryPoint
impl Args for EntryPoint
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Command for EntryPoint
impl Command for EntryPoint
Sourcefn description() -> &'static str
fn description() -> &'static str
Description of this program
Authors of this program
Sourcefn parse_args<T, I>(into_args: I) -> Self
fn parse_args<T, I>(into_args: I) -> Self
Parse command-line arguments from an iterator
Sourcefn parse_env_args() -> Selfwhere
Self: Parser,
fn parse_env_args() -> Selfwhere
Self: Parser,
Parse command-line arguments from the environment
Sourceimpl CommandFactory for EntryPoint
impl CommandFactory for EntryPoint
Sourceimpl Configurable<RusticConfig> for EntryPoint
This trait allows you to define how application configuration is loaded.
impl Configurable<RusticConfig> for EntryPoint
This trait allows you to define how application configuration is loaded.
Sourcefn config_path(&self) -> Option<PathBuf>
fn config_path(&self) -> Option<PathBuf>
Location of the configuration file
Sourcefn process_config(
&self,
_config: RusticConfig,
) -> Result<RusticConfig, FrameworkError>
fn process_config( &self, _config: RusticConfig, ) -> Result<RusticConfig, FrameworkError>
Apply changes to the config after it’s been loaded, e.g. overriding values in a config file using command-line options.
Sourceimpl Debug for EntryPoint
impl Debug for EntryPoint
Sourceimpl FromArgMatches for EntryPoint
impl FromArgMatches for EntryPoint
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for EntryPoint
impl Parser for EntryPoint
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)