pub struct GlobalOptions {Show 16 fields
pub profile_substitute_env: bool,
pub use_profiles: Vec<String>,
pub group_by: Option<SnapshotGroupCriterion>,
pub dry_run: bool,
pub dry_run_warmup: bool,
pub check_index: bool,
pub logging_options: LoggingOptions,
pub progress_options: ProgressOptions,
pub hooks: Hooks,
pub env: BTreeMap<String, String>,
pub prometheus: Option<Url>,
pub prometheus_user: Option<String>,
pub prometheus_pass: Option<String>,
pub metrics_labels: BTreeMap<String, String>,
pub opentelemetry: Option<Url>,
pub show_time_offset: bool,
}Expand description
Global options
These options are available for all commands.
Fields
profile_substitute_env: boolSubstitute environment variables in profiles
use_profiles: Vec<String>Config profile to use. This parses the file <PROFILE>.toml in the config directory.
[default: “rustic”]
group_by: Option<SnapshotGroupCriterion>Group snapshots by any combination of host,label,paths,tags, e.g. to find the latest snapshot [default: “host,label,paths”]
dry_run: boolOnly show what would be done without modifying anything. Does not affect read-only commands.
dry_run_warmup: boolAdditional to dry run, but still issue warm-up command if configured
check_index: boolCheck if index matches pack files and read pack headers if necessary
logging_options: LoggingOptionsSettings to customize logging
progress_options: ProgressOptionsSettings to customize progress bars
hooks: HooksHooks
env: BTreeMap<String, String>List of environment variables to set (only in config file)
prometheus: Option<Url>Push metrics to a Prometheus Pushgateway
prometheus_user: Option<String>Authenticate to Prometheus Pushgateway using this user
prometheus_pass: Option<String>Authenticate to Prometheus Pushgateway using this password
metrics_labels: BTreeMap<String, String>Additional labels to set to generated metrics
opentelemetry: Option<Url>OpenTelemetry metrics endpoint (HTTP Protobuf)
show_time_offset: boolShow time offsets instead of converting to system time zone
Implementations
Sourceimpl GlobalOptions
impl GlobalOptions
pub fn is_metrics_configured(&self) -> bool
pub fn format_timestamp(&self, timestamp: Timestamp) -> String
pub fn format_time(&self, time: &Zoned) -> impl Display