pub struct RusticConfig {
pub global: GlobalOptions,
pub repository: AllRepositoryOptions,
pub snapshot_filter: SnapshotFilter,
pub backup: BackupCmd,
pub copy: CopyCmd,
pub forget: ForgetOptions,
pub mount: MountCmd,
pub webdav: WebDavCmd,
}Expand description
Fields
global: GlobalOptionsGlobal options
repository: AllRepositoryOptionsRepository options
snapshot_filter: SnapshotFilterSnapshot filter options
backup: BackupCmdBackup options
copy: CopyCmdCopy options
forget: ForgetOptionsForget options
mount: MountCmdmount options
webdav: WebDavCmdwebdav options
Implementations
Sourceimpl RusticConfig
impl RusticConfig
Sourcepub fn merge_profile(
&mut self,
profile: &str,
merge_logs: &mut Vec<(Level, String)>,
level_missing: Level,
) -> Result<(), FrameworkError>
pub fn merge_profile( &mut self, profile: &str, merge_logs: &mut Vec<(Level, String)>, level_missing: Level, ) -> Result<(), FrameworkError>
Merge a profile into the current config by reading the corresponding config file. Also recursively merge all profiles given within this config file.
Arguments
profile- name of the profile to mergemerge_logs- Vector to collect logs during merginglevel_missing- The log level to use if this profile is missing. Recursive calls will produce a Warning.