Struct rustic_rs::config::GlobalOptions
source · pub struct GlobalOptions {
pub use_profile: Vec<String>,
pub dry_run: bool,
pub log_level: Option<String>,
pub log_file: Option<PathBuf>,
pub progress_options: ProgressOptions,
pub env: HashMap<String, String>,
}Expand description
Global options
These options are available for all commands.
Fields
use_profile: Vec<String>Config profile to use. This parses the file <PROFILE>.toml in the config directory.
[default: “rustic”]
dry_run: boolOnly show what would be done without modifying anything. Does not affect read-only commands.
log_level: Option<String>Use this log level [default: info]
log_file: Option<PathBuf>Write log messages to the given file instead of printing them.
Note
Warnings and errors are still additionally printed unless they are ignored by --log-level
progress_options: ProgressOptionsSettings to customize progress bars
env: HashMap<String, String>List of environment variables to set (only in config file)